@@ -31,7 +31,6 @@ import org.ovirt.engine.core.bll.validator.storage.DiskImagesValidator;
 import org.ovirt.engine.core.bll.validator.storage.MultipleStorageDomainsValidator;
 import org.ovirt.engine.core.bll.validator.storage.StoragePoolValidator;
 import org.ovirt.engine.core.common.AuditLogType;
-import org.ovirt.engine.core.common.FeatureSupported;
 import org.ovirt.engine.core.common.VdcObjectType;
 import org.ovirt.engine.core.common.action.ActionParametersBase;
 import org.ovirt.engine.core.common.action.ActionParametersBase.EndProcedure;
@@ -150,7 +149,7 @@ public class RemoveSnapshotCommand<T extends RemoveSnapshotParameters> extends V
         final Snapshot snapshot = snapshotDao.get(getParameters().getSnapshotId());
 
         boolean snapshotHasImages = hasImages();
-        boolean removeSnapshotMemory = isMemoryVolumeRemoveable(snapshot);
+        boolean removeSnapshotMemory = isMemoryVolumeRemovable(snapshot);
 
         // If the VM hasn't got any images and memory - simply remove the snapshot.
         // No need for locking, VDSM tasks, and all that jazz.
@@ -188,9 +187,9 @@ public class RemoveSnapshotCommand<T extends RemoveSnapshotParameters> extends V
 
     /**
      * There is a one to many relation between memory volumes and snapshots, so memory
-     * volumes should be removed only if the only snapshot that points to them is removed
+     * volumes should be removed only if the only snapshot that points to them is removed.
      */
-    protected boolean isMemoryVolumeRemoveable(Snapshot snapshot) {
+    private boolean isMemoryVolumeRemovable(Snapshot snapshot) {
         return snapshot.containsMemory() && snapshotDao.getNumOfSnapshotsByDisks(snapshot) == 1;
     }
 
@@ -252,7 +251,7 @@ public class RemoveSnapshotCommand<T extends RemoveSnapshotParameters> extends V
             handleCinderSnapshotDisks(cinderDisks);
         }
 
-        managedBlockDisks.forEach(disk -> removeManagedBlockSnapshot(disk));
+        managedBlockDisks.forEach(this::removeManagedBlockSnapshot);
     }
 
     private void removeManagedBlockSnapshot(ManagedBlockStorageDisk disk) {
@@ -418,7 +417,7 @@ public class RemoveSnapshotCommand<T extends RemoveSnapshotParameters> extends V
      *
      * @return True if there is enough space in all relevant storage domains. False otherwise.
      */
-    protected boolean validateStorageDomains() {
+    private boolean validateStorageDomains() {
         MultipleStorageDomainsValidator storageDomainsValidator = getStorageDomainsValidator(getStoragePoolId(), getStorageDomainsIds());
         if (DisksFilter.filterImageDisks(getSourceImages()).isEmpty()) {
             return true;
@@ -431,13 +430,12 @@ public class RemoveSnapshotCommand<T extends RemoveSnapshotParameters> extends V
     }
 
     /**
-     * The base snapshot is the parent of the top snapshot. This is reversed the if old cold merge
-     * is performed (pre-4.1).
+     * The base snapshot is the parent of the top snapshot.
      *
      * @param snapshots list of the parent snapshot disks
      * @return list of subchains which contain the base and top snapshots.
      */
-    protected List<SubchainInfo> getAllDisksSnapshot(List<DiskImage> snapshots) {
+    private List<SubchainInfo> getAllDisksSnapshot(List<DiskImage> snapshots) {
         Set<DiskImage> topSnapshots = diskImageDao.getAllSnapshotsForParents(
                 snapshots
                     .stream()
@@ -451,13 +449,7 @@ public class RemoveSnapshotCommand<T extends RemoveSnapshotParameters> extends V
 
         return topSnapshots
             .stream()
-            .map(topSnapshot -> {
-                if (!isQemuimgCommitSupported() && getSnapshotActionType() == ActionType.RemoveSnapshotSingleDisk) {
-                    return new SubchainInfo(topSnapshot, baseSnapshotMap.get(topSnapshot.getParentId()));
-                } else {
-                    return new SubchainInfo(baseSnapshotMap.get(topSnapshot.getParentId()), topSnapshot);
-                }
-            })
+            .map(topSnapshot -> new SubchainInfo(baseSnapshotMap.get(topSnapshot.getParentId()), topSnapshot))
             .collect(Collectors.toList());
     }
 
@@ -475,15 +467,15 @@ public class RemoveSnapshotCommand<T extends RemoveSnapshotParameters> extends V
         addValidationMessage(EngineMessage.VAR__ACTION__REMOVE);
     }
 
-    protected boolean validateVmSnapshotDisksNotDuringMerge() {
+    private boolean validateVmSnapshotDisksNotDuringMerge() {
         return validate(snapshotsValidator.vmSnapshotDisksNotDuringMerge(getVmId(), getParameters().getSnapshotId()));
     }
 
-    protected boolean validateVmNotInPreview() {
+    private boolean validateVmNotInPreview() {
         return validate(snapshotsValidator.vmNotInPreview(getVmId()));
     }
 
-    protected boolean validateSnapshotExists() {
+    private boolean validateSnapshotExists() {
         return validate(snapshotsValidator.snapshotExists(getVmId(), getParameters().getSnapshotId()));
     }
 
@@ -571,10 +563,7 @@ public class RemoveSnapshotCommand<T extends RemoveSnapshotParameters> extends V
         if (getVm().isQualifiedForLiveSnapshotMerge()) {
             return ActionType.RemoveSnapshotSingleDiskLive;
         }
-        if (isQemuimgCommitSupported()) {
-            return ActionType.ColdMergeSnapshotSingleDisk;
-        }
-        return ActionType.RemoveSnapshotSingleDisk;
+        return ActionType.ColdMergeSnapshotSingleDisk;
     }
 
     @Override
@@ -600,14 +589,10 @@ public class RemoveSnapshotCommand<T extends RemoveSnapshotParameters> extends V
             return null;
         }
 
-        if (vm.isQualifiedForLiveSnapshotMerge() || getParameters().isUseCinderCommandCallback() ||
-                isQemuimgCommitSupported()) {
+        if (vm.isQualifiedForLiveSnapshotMerge() || getParameters().isUseCinderCommandCallback()
+                || getSnapshotActionType() == ActionType.ColdMergeSnapshotSingleDisk) {
             return callbackProvider.get();
         }
         return null;
     }
-
-    private boolean isQemuimgCommitSupported() {
-        return FeatureSupported.isQemuimgCommitSupported(getStoragePool().getCompatibilityVersion());
-    }
 }
