@@ -1,10 +1,12 @@
 package org.ovirt.engine.core.bll.validator;
 
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Objects;
 import java.util.Set;
+import java.util.function.Supplier;
 import java.util.stream.Collectors;
 
 import org.apache.commons.collections.CollectionUtils;
@@ -14,6 +16,7 @@ import org.ovirt.engine.core.bll.ValidationResult;
 import org.ovirt.engine.core.bll.utils.VersionSupport;
 import org.ovirt.engine.core.common.FeatureSupported;
 import org.ovirt.engine.core.common.businessentities.ArchitectureType;
+import org.ovirt.engine.core.common.businessentities.BiosType;
 import org.ovirt.engine.core.common.businessentities.Cluster;
 import org.ovirt.engine.core.common.businessentities.MigrateOnErrorOptions;
 import org.ovirt.engine.core.common.businessentities.StoragePool;
@@ -34,6 +37,7 @@ import org.ovirt.engine.core.dao.SupportedHostFeatureDao;
 import org.ovirt.engine.core.dao.VdsDao;
 import org.ovirt.engine.core.dao.VmDao;
 import org.ovirt.engine.core.dao.gluster.GlusterVolumeDao;
+import org.ovirt.engine.core.utils.MemoizingSupplier;
 
 public class ClusterValidator {
 
@@ -45,21 +49,17 @@ public class ClusterValidator {
     private final StoragePoolDao dataCenterDao;
     private StoragePool dataCenter;
     private StoragePool dataCenterOfNewCluster;
-    private VdsDao vdsDao;
-    private VmDao vmDao;
     private GlusterVolumeDao glusterVolumeDao;
     private ClusterFeatureDao clusterFeatureDao;
     private SupportedHostFeatureDao hostFeatureDao;
 
     private CpuFlagsManagerHandler cpuFlagsManagerHandler;
     private Cluster newCluster;
-    private List<VDS> allForCluster;
 
-    private List<VM> vmList;
-    private boolean hasVmOrHost;
-    private boolean sameCpuNames;
     private int compareCompatibilityVersions;
 
+    private final Supplier<List<VDS>> allHostsForCluster;
+    private final Supplier<List<VM>> allVmsForCluster;
 
     public ClusterValidator(
             ClusterDao clusterDao,
@@ -70,6 +70,9 @@ public class ClusterValidator {
         this.clusterDao = clusterDao;
         this.dataCenterDao = dataCenterDao;
         this.cpuFlagsManagerHandler = cpuFlagsManagerHandler;
+
+        allHostsForCluster = () -> null;
+        allVmsForCluster = () -> null;
     }
 
     public ClusterValidator(ClusterDao clusterDao,
@@ -87,11 +90,12 @@ public class ClusterValidator {
         this.dataCenterDao = dataCenterDao;
         this.cpuFlagsManagerHandler = cpuFlagsManagerHandler;
         this.newCluster = newCluster;
-        this.vdsDao = vdsDao;
-        this.vmDao = vmDao;
         this.glusterVolumeDao = glusterVolumeDao;
         this.clusterFeatureDao = clusterFeatureDao;
         this.hostFeatureDao = hostFeatureDao;
+
+        allHostsForCluster = new MemoizingSupplier<>(() -> vdsDao.getAllForCluster(cluster.getId()));
+        allVmsForCluster = new MemoizingSupplier<>(() -> vmDao.getAllForCluster(cluster.getId()));
     }
 
     public ValidationResult nameNotUsed() {
@@ -219,12 +223,11 @@ public class ClusterValidator {
      * decreasing of compatibility version is only allowed when no hosts exist
      */
     public ValidationResult decreaseClusterWithHosts() {
-        allForCluster = vdsDao.getAllForCluster(cluster.getId());
         compareCompatibilityVersions = newCluster.getCompatibilityVersion().compareTo(cluster.getCompatibilityVersion());
         return ValidationResult
                 .failWith(EngineMessage.ACTION_TYPE_FAILED_CANNOT_DECREASE_CLUSTER_WITH_HOSTS_COMPATIBILITY_VERSION)
                 .when(compareCompatibilityVersions < 0
-                        && !allForCluster.isEmpty());
+                        && !allHostsForCluster.get().isEmpty());
     }
 
     /**
@@ -258,8 +261,7 @@ public class ClusterValidator {
      * if cpu changed from intel to amd (or backwards) and there are vds in this cluster, cannot update
      */
     public ValidationResult updateCpuIllegal(boolean cpusExist, boolean cpusSameManufacture) {
-        allForCluster = vdsDao.getAllForCluster(cluster.getId());
-        boolean allVdssInMaintenance = areAllVdssInMaintenance(allForCluster);
+        boolean allVdssInMaintenance = areAllVdssInMaintenance(allHostsForCluster.get());
         return ValidationResult.failWith(EngineMessage.CLUSTER_CANNOT_UPDATE_CPU_ILLEGAL)
                 .when(newCluster.supportsVirtService()
                         && (!"".equals(cluster.getCpuName()) || !"".equals(newCluster.getCpuName()))
@@ -272,18 +274,14 @@ public class ClusterValidator {
      * cannot change the processor architecture while there are attached hosts or VMs to the cluster
      */
     public ValidationResult architectureIsLegal(boolean isArchitectureUpdatable) {
-        vmList = vmDao.getAllForCluster(cluster.getId());
-        allForCluster = vdsDao.getAllForCluster(cluster.getId());
-        hasVmOrHost = !vmList.isEmpty() || !allForCluster.isEmpty();
+        boolean hasVmOrHost = !allVmsForCluster.get().isEmpty() || !allHostsForCluster.get().isEmpty();
         return ValidationResult.failWith(EngineMessage.CLUSTER_CANNOT_UPDATE_CPU_ARCHITECTURE_ILLEGAL)
                 .when(newCluster.supportsVirtService() && !isArchitectureUpdatable && hasVmOrHost);
     }
 
     public ValidationResult cpuUpdatable() {
-        vmList = vmDao.getAllForCluster(cluster.getId());
-        allForCluster = vdsDao.getAllForCluster(cluster.getId());
-        hasVmOrHost = !vmList.isEmpty() || !allForCluster.isEmpty();
-        sameCpuNames = Objects.equals(cluster.getCpuName(), newCluster.getCpuName());
+        boolean hasVmOrHost = !allVmsForCluster.get().isEmpty() || !allHostsForCluster.get().isEmpty();
+        boolean sameCpuNames = Objects.equals(cluster.getCpuName(), newCluster.getCpuName());
         boolean isCpuUpdatable = cpuFlagsManagerHandler.isCpuUpdatable(cluster.getCpuName(), cluster.getCompatibilityVersion());
         boolean isOldCPUEmpty = StringUtils.isEmpty(cluster.getCpuName());
         return ValidationResult.failWith(EngineMessage.CLUSTER_CPU_IS_NOT_UPDATABLE)
@@ -294,8 +292,7 @@ public class ClusterValidator {
      * can't change cluster version when a VM is in preview
      */
     public ValidationResult vmInPrev() {
-        vmList = vmDao.getAllForCluster(cluster.getId());
-        List<String> vmInPreviewNames = vmList.stream()
+        List<String> vmInPreviewNames = allVmsForCluster.get().stream()
                 .filter(VM::isPreviewSnapshot)
                 .map(VM::getName)
                 .collect(Collectors.toList());
@@ -305,8 +302,7 @@ public class ClusterValidator {
     }
 
     protected List<VDS> upVdss() {
-        allForCluster = vdsDao.getAllForCluster(cluster.getId());
-        return allForCluster.stream()
+        return allHostsForCluster.get().stream()
                 .filter(v -> v.getStatus() == VDSStatus.Up)
                 .collect(Collectors.toList());
     }
@@ -377,13 +373,11 @@ public class ClusterValidator {
     }
 
     protected boolean isAllowClusterWithVirtGluster() {
-        Boolean allowVirGluster = Config.<Boolean> getValue(ConfigValues.AllowClusterWithVirtGlusterEnabled);
-        return allowVirGluster;
+        return Config.<Boolean> getValue(ConfigValues.AllowClusterWithVirtGlusterEnabled);
     }
 
     public ValidationResult disableVirt() {
-        vmList = vmDao.getAllForCluster(cluster.getId());
-        boolean hasVms = !vmList.isEmpty();
+        boolean hasVms = !allVmsForCluster.get().isEmpty();
         return ValidationResult.failWith(EngineMessage.CLUSTER_CANNOT_DISABLE_VIRT_WHEN_CLUSTER_CONTAINS_VMS)
                 .when(hasVms && !newCluster.supportsVirtService());
     }
@@ -401,14 +395,15 @@ public class ClusterValidator {
     }
 
     protected ArchitectureType getArchitecture() {
-        if (StringUtils.isNotEmpty(newCluster.getCpuName())) {
-            return cpuFlagsManagerHandler.getArchitectureByCpuName(newCluster.getCpuName(),
-                    newCluster.getCompatibilityVersion());
-        } else if (newCluster.getArchitecture() == null) {
+        Cluster eCluster = newCluster != null ? newCluster : cluster;
+        if (StringUtils.isNotEmpty(eCluster.getCpuName())) {
+            return cpuFlagsManagerHandler.getArchitectureByCpuName(eCluster.getCpuName(),
+                    eCluster.getCompatibilityVersion());
+        } else if (eCluster.getArchitecture() == null) {
             return ArchitectureType.undefined;
         }
 
-        return cluster.getArchitecture();
+        return eCluster.getArchitecture();
     }
 
     public ValidationResult migrationOnError(ArchitectureType architectureType) {
@@ -421,6 +416,17 @@ public class ClusterValidator {
         return FeatureSupported.isMigrationSupported(arch, cluster.getCompatibilityVersion());
     }
 
+    public ValidationResult nonDefaultBiosType() {
+        Cluster eCluster = newCluster != null ? newCluster : cluster;
+        ArchitectureType architecture = getArchitecture();
+        return ValidationResult.failWith(EngineMessage.NON_DEFAULT_BIOS_TYPE_FOR_X86_ONLY)
+                .when(FeatureSupported.isBiosTypeSupported(eCluster.getCompatibilityVersion())
+                    && eCluster.getBiosType() != null
+                    && eCluster.getBiosType() != BiosType.CLUSTER_DEFAULT
+                    && eCluster.getBiosType() != BiosType.I440FX_SEA_BIOS
+                    && architecture.getFamily() != ArchitectureType.x86);
+    }
+
     private boolean attestationServerEnabled() {
         String attestationServer = Config.getValue(ConfigValues.AttestationServer);
         return StringUtils.isNotEmpty(attestationServer);
@@ -439,4 +445,22 @@ public class ClusterValidator {
         }
         return dataCenterOfNewCluster;
     }
+
+    public List<String> getLowDeviceSpaceVolumes() {
+        List<String> volumes = new ArrayList<>();
+        if(cluster.supportsGlusterService()) {
+            List<GlusterVolumeEntity> glusterVolumeEntities = glusterVolumeDao.getByClusterId(cluster.getId());
+            if(glusterVolumeEntities != null && !glusterVolumeEntities.isEmpty()) {
+                for(GlusterVolumeEntity glusterVolumeEntity: glusterVolumeEntities) {
+                    if (((glusterVolumeEntity.getAdvancedDetails().getCapacityInfo().getUsedSize().doubleValue()
+                            / glusterVolumeEntity.getAdvancedDetails().getCapacityInfo().getTotalSize().doubleValue())
+                            * 100) > (Integer)Config.getValue(ConfigValues.StorageDeviceSpaceLimit)) {
+                        volumes.add(glusterVolumeEntity.getName());
+                    }
+                }
+            }
+        }
+        return volumes;
+    }
+
 }
