@@ -1,17 +1,6 @@
 /*
-Copyright (c) 2015 Red Hat, Inc.
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+ * Copyright oVirt Authors
+ * SPDX-License-Identifier: Apache-2.0
 */
 
 package org.ovirt.engine.api.restapi.resource;
@@ -47,6 +36,7 @@ import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.AttachDetachVmDiskParameters;
 import org.ovirt.engine.core.common.action.ExportRepoImageParameters;
 import org.ovirt.engine.core.common.action.MoveDisksParameters;
+import org.ovirt.engine.core.common.action.UpdateDiskParameters;
 import org.ovirt.engine.core.common.action.VmDiskOperationParameterBase;
 import org.ovirt.engine.core.common.asynctasks.EntityInfo;
 import org.ovirt.engine.core.common.businessentities.VmDeviceId;
@@ -142,8 +132,8 @@ public class BackendVmDiskResourceTest
 
         setUriInfo(
             setUpActionExpectations(
-                ActionType.UpdateVmDisk,
-                VmDiskOperationParameterBase.class,
+                ActionType.UpdateDisk,
+                UpdateDiskParameters.class,
                 new String[] { "VmId", "DiskInfo.WipeAfterDelete" },
                 new Object[] { VM_ID, Boolean.FALSE },
                 true,
@@ -160,8 +150,8 @@ public class BackendVmDiskResourceTest
         setUpDiskVmElementExpectations();
         setUriInfo(
             setUpActionExpectations(
-                ActionType.UpdateVmDisk,
-                VmDiskOperationParameterBase.class,
+                ActionType.UpdateDisk,
+                UpdateDiskParameters.class,
                 new String[] { "VmId", "DiskVmElement.ReadOnly" },
                 new Object[] { VM_ID, Boolean.TRUE },
                 true,
