@@ -14,6 +14,7 @@ import com.google.gwt.event.shared.HasHandlers;
 public class EntityModel<T> extends Model implements HasHandlers, HasEntity<T> {
 
     private Event<EventArgs> privateEntityChangedEvent;
+    private boolean entityPresent = true;
 
     @Override
     public Event<EventArgs> getEntityChangedEvent() {
@@ -43,6 +44,16 @@ public class EntityModel<T> extends Model implements HasHandlers, HasEntity<T> {
         }
     }
 
+    @Override
+    public boolean isEntityPresent() {
+        return entityPresent;
+    }
+
+    @Override
+    public void setEntityPresent(boolean flag) {
+        this.entityPresent = flag;
+    }
+
     @Override
     public EntityModel<T> setIsChangeable(boolean value) {
         return setIsChangeable(value, null);
@@ -125,6 +136,11 @@ public class EntityModel<T> extends Model implements HasHandlers, HasEntity<T> {
             return;
         }
 
+        if (!isEntityPresent()) {
+            setIsValid(false);
+            return;
+        }
+
         for (IValidation validation : validations) {
             ValidationResult result = validation.validate(getEntity());
             if (!result.getSuccess()) {
