@@ -8,12 +8,8 @@ import org.ovirt.engine.core.common.AuditLogType;
 import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.TransferDiskImageParameters;
 import org.ovirt.engine.core.common.action.TransferImageStatusParameters;
-import org.ovirt.engine.core.common.businessentities.VDS;
 import org.ovirt.engine.core.common.businessentities.storage.ImageTransfer;
 import org.ovirt.engine.core.common.businessentities.storage.ImageTransferPhase;
-import org.ovirt.engine.core.common.queries.IdQueryParameters;
-import org.ovirt.engine.core.common.queries.QueryReturnValue;
-import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.common.utils.SizeConverter;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.ui.frontend.AsyncQuery;
@@ -86,7 +82,7 @@ public class UploadImageHandler {
     private Guid vdsId;
     private Guid diskId;
     private Element fileUploadElement;
-    private Boolean getImageTicketSupported;
+    private Guid storageDomainId;
 
     private Event<EventArgs> uploadFinishedEvent =
             new Event<>("UploadFinished", UploadImageHandler.class); //$NON-NLS-1$
@@ -188,22 +184,6 @@ public class UploadImageHandler {
         this.fileUploadElement = fileUploadElement;
     }
 
-    public Boolean getGetImageTicketSupported() {
-        if (getImageTicketSupported == null) {
-            Frontend.getInstance().runQuery(QueryType.GetVdsByVdsId, new IdQueryParameters(getVdsId()),
-                    new AsyncQuery<QueryReturnValue>(returnValue -> {
-                        VDS vds = returnValue.getReturnValue();
-                        setGetImageTicketSupported(AsyncDataProvider.getInstance().isGetImageTicketSupported(
-                                vds.getClusterCompatibilityVersion()));
-                    }));
-        }
-        return getImageTicketSupported;
-    }
-
-    public void setGetImageTicketSupported(boolean getImageTicketSupported) {
-        this.getImageTicketSupported = getImageTicketSupported;
-    }
-
     public void setDiskId(Guid diskId) {
         this.diskId = diskId;
     }
@@ -220,6 +200,14 @@ public class UploadImageHandler {
         return uploadFinishedEvent;
     }
 
+    public Guid getStorageDomainId() {
+        return storageDomainId;
+    }
+
+    public void setStorageDomainId(Guid storageDomainId) {
+        this.storageDomainId = storageDomainId;
+    }
+
     /**
      * A single upload image handler
      *
@@ -279,9 +267,9 @@ public class UploadImageHandler {
         Scheduler.get().scheduleFixedDelay(() -> {
             log.info("Polling for status"); //$NON-NLS-1$
             TransferImageStatusParameters statusParameters = new TransferImageStatusParameters(getCommandId());
+            statusParameters.setStorageDomainId(getStorageDomainId());
 
             ImageTransfer updates = new ImageTransfer();
-            updateBytesSent(updates);
             updates.setMessage(getProgressStr());
             statusParameters.setUpdates(updates);
 
@@ -291,13 +279,6 @@ public class UploadImageHandler {
         }, POLLING_DELAY_MS);
     }
 
-    private void updateBytesSent(ImageTransfer updates) {
-        if (getVdsId() != null && getImageTicketId() != null && Boolean.FALSE.equals(getGetImageTicketSupported())) {
-            // Old engines update the bytesSent here, new engines update it in TransferImageCommand.
-            updates.setBytesSent(getBytesSent());
-        }
-    }
-
     private void respondToPollStatus(FrontendActionAsyncResult result) {
         if (result.getReturnValue() != null && result.getReturnValue().getSucceeded()) {
             ImageTransfer rv = result.getReturnValue().getActionReturnValue();
@@ -405,6 +386,7 @@ public class UploadImageHandler {
 
         ImageTransfer updates = new ImageTransfer();
         TransferImageStatusParameters statusParameters = new TransferImageStatusParameters(getCommandId(), updates);
+        statusParameters.setStorageDomainId(getStorageDomainId());
 
         if (getUploadState() == UploadState.SUCCESS) {
             setProgressStr("Finalizing success..."); //$NON-NLS-1$
@@ -540,6 +522,17 @@ public class UploadImageHandler {
             }
 
             var address = proxyUri + '/' + resourceId;
+
+            // On the last request we want to close the connection and flush.
+            // This will close imageio backend so we can deactivate the volume
+            // on block storage. On all other requests we want to avoid
+            // flushing for better performance.
+            if (bytesSent + bytesToSend === endByte) {
+                address += '?close=y';
+            } else {
+                address += '?flush=n';
+            }
+
             var contentRange = 'bytes ' + bytesSent + '-' + (bytesSent + bytesToSend - 1) + '/' + endByte;
 
             xhr.open('PUT', address);
@@ -696,6 +689,7 @@ public class UploadImageHandler {
 
             TransferImageStatusParameters parameters = new TransferImageStatusParameters(rv.getId());
             parameters.setUpdates(updates);
+            parameters.setStorageDomainId(getStorageDomainId());
             Frontend.getInstance().runAction(ActionType.TransferImageStatus, parameters,
                     this::initiateResumeUploadStartTransfer);
         } else {
